@@ -194,14 +194,15 @@ class OperatorElementOpDone(QRunnable):
 
         cfgElement = [x for x in self.currentConfig if x['Id'] == self.id][0]
 
-
-
         if cfgElement['Config']['GeneralConfig']['Logging'] and self.record.message: # Log Message enabled
             if isinstance(self.record.data, PythonicError):
                 logging.warning('{} - {}'.format(cfgElement['ObjectName'], self.record.message))
             else:
                 logging.info('{} - {}'.format(cfgElement['ObjectName'], self.record.message))
 
+            # forward message to GUI so that the message can be 
+            # optionally displayed in the message sidebar
+
             data = {
                 'Id'        : cfgElement['Id'],
                 'ObjectName': cfgElement['ObjectName'],
@@ -221,6 +222,9 @@ class OperatorElementOpDone(QRunnable):
 
         if cfgElement['Config']['GeneralConfig']['Debug'] : # Log Output enabled
 
+            # convert the payload to string to that the data can be
+            # optionally displayed in the output sidebar
+
             data = {
                 'Id'        : cfgElement['Id'],
                 'AreaNo'    : cfgElement['AreaNo'],
@@ -361,8 +365,13 @@ class Operator(QObject):
             logging.info("Autostart " + startElement['ObjectName'])
             self.createProcHandle(startElement)
 
-    def getIdent(self):
+    def updateConfig(self, config):
 
+        logging.debug('Operator::updateConfig() called')
+        self.currentConfig = config
+
+    def getIdent(self):
+        # generate a new process handle identifier
         self.identGenMutex.lock()
         
         self.n_ident += 1 
@@ -377,15 +386,15 @@ class Operator(QObject):
 
         return self.n_ident
 
-    def startExec(self, id, config):
+    def startExec(self, id):
         logging.debug('Operator::startExec() called - id: 0x{:08x}'.format(id))
         ## create processor and forward config and start filename
 
-        self.currentConfig = config
+        # self.currentConfig = config
         # https://stackoverflow.com/questions/34609935/passing-a-function-with-two-arguments-to-filter-in-python
 
         # return first element which matches the ID
-        startElement = [x for x in config if x['Id'] == id][0]
+        startElement = [x for x in self.currentConfig if x['Id'] == id][0]
 
         self.createProcHandle(startElement)
 
@@ -458,6 +467,7 @@ class Operator(QObject):
         self.threadpool.start(stateOperator)
         
     def updateStatus(self, element, status):
+
         #start highlight
         # area
         # id
